---
title: '[공지] 네이버페이 서비스 점검 공지'
category: 공지사항
tags:
  - 공지사항
datetime: 2023-10-16T15:00:00.000Z
---

안녕하세요, 포트원 고객지원팀입니다.

2023년 10월 21일 02:00 \~ 06:00 일자에 네이버페이 내부적으로 시스템 점검 일정이 예정되어있어 미리 공지· 공유드립니다.

아래 내용 참고하시어 운영간 차질 없으시기 바랍니다.

감사합니다.

---

안녕하세요. 네이버페이입니다.

네이버페이 전체 서비스 점검이 예정되어 있어 안내드립니다.

아래 안내 사항 확인하시어 운영 시 참고 부탁드립니다.

- 점검 기간 : 2023년 10월 21일 02:00 \~ 06:00
- 점검 영향 : 네이버페이 전체 서비스 일시 중단
  - 네이버페이 이용 고객사(간편결제, 정기/반복결제, 인증형결제)에 제공되는 모든 API에 대해 점검 시간 중 사용이 불가합니다.
  - 요청 시 실패 응답을 받게 되며 호출 실패한 건은 점검 시간 이후 고객사측에서 재호출을 해야 합니다. \
    취소 API 또한 점검 시간 종료 후 재호출이 필요합니다.
- 실패 응답으로는 아래의 내용이 전달될 예정입니다. (message 내용은 변경될 수 있습니다.)
  - "code" : "MaintenanceOngoing"
  - "message" : "시스템 점검 중입니다. (2023-10-21T02:00+09:00 \~ 2023-10-21T06:00+09:00)

점검 시간 전에 요청된 정산/적립건에 대해서는 정상적으로 정산/적립 처리됩니다.

점검 시간 중의 정산 적립 API 요청은 실패하기에 점검 종료 후 재호출이 필요합니다.

점검 시간 중 결제창 접속 및 js sdk 요청 시 시스템 점검 안내가 사용자에게 표시됩니다.

서비스 이용에 불편을 드려 죄송합니다.

더욱 안정적인 서비스 제공으로 보답하는 네이버페이가 되겠습니다.

감사합니다.
